import { SeatersApiContext } from '../../seaters-api';
import { PagedResult } from '../paged-result';
import { PagingOptions } from '../paging-options';
import { SeatersApiController } from '../seaters-api-controller';
import * as admin from './admin-types';
import { profiling, survey } from '../../services/index';
import { VenueConfig, Event } from './event-venue';
import { Badge, Category, BADGE_STATUS } from '../fan';
export declare class AdminApi extends SeatersApiController {
    private apiContext;
    constructor(apiContext: SeatersApiContext);
    getUsers(page: PagingOptions): Promise<PagedResult<admin.User>>;
    searchUsers(query: admin.UserSearchQuery, page: PagingOptions): Promise<PagedResult<admin.User>>;
    getUser(id: string): Promise<admin.User>;
    updateUser(user: admin.User): Promise<admin.User>;
    deleteUser(id: string): Promise<admin.User>;
    createUser(user: admin.User): Promise<admin.User>;
    getUserOwnerships(userId: string, page: PagingOptions): Promise<PagedResult<admin.FanGroupOwnership>>;
    createUserOwnership(ownership: admin.FanGroupOwnership): Promise<admin.FanGroupOwnership>;
    deleteUserOwnership(ownership: admin.FanGroupOwnership): Promise<admin.FanGroupOwnership>;
    getEvent(eventId: string): Promise<admin.FanGroup>;
    getFanGroup(fanGroupId: string): Promise<admin.FanGroup>;
    getFanGroupProtectionCodes(fanGroupId: string, page: PagingOptions): Promise<PagedResult<admin.FanGroupProtectionCode>>;
    getFanGroupWaitingLists(fanGroupId: string, page: PagingOptions): Promise<PagedResult<admin.WaitingList>>;
    getWaitingList(waitingListId: string): Promise<admin.WaitingList>;
    updateWaitingList(wl: admin.UpdateWaitingList): Promise<admin.WaitingList>;
    deleteWaitingList(waitingListId: string): Promise<any>;
    scheduleClosingDate(waitingListId: string, date: string): Promise<any>;
    createFanGroupProtectionCode(fanGroupId: string, code: string, maxTimesUsed: number): Promise<admin.FanGroupProtectionCode>;
    deleteFanGroupProtectionCode(fanGroupId: string, code: string): Promise<any>;
    importFanGroupProtectionCodes(fanGroupId: string, fileId: string): Promise<any>;
    requestFanGroupBackgroundImageUpload(fanGroupId: string, fileName?: string): Promise<admin.OneTimeFile>;
    requestFanGroupCoverImageUpload(fanGroupId: string, fileName?: string): Promise<admin.OneTimeFile>;
    requestFanGroupProfileImageUpload(fanGroupId: string, fileName?: string): Promise<admin.OneTimeFile>;
    requestOneTimeFileUpload(fileName?: string): Promise<admin.OneTimeFile>;
    /**
     * Upload a onetime file
     * @param oneTimeFileUrl url of a OneTimeFile returned by requestOneTimeFileUpload
     * @param data for browsers: HTMLInputElement, for node: not supported
     */
    uploadOneTimeFile(oneTimeFileUrl: string, data: any): Promise<any>;
    getCategories(options: PagingOptions): Promise<PagedResult<profiling.ProfilingCategory>>;
    getCategory(id: string): Promise<profiling.ProfilingCategory>;
    createCategory(category: profiling.ProfilingCategory): Promise<profiling.ProfilingCategory>;
    updateCategory(category: profiling.ProfilingCategory): Promise<profiling.ProfilingCategory>;
    deleteCategory(id: string): Promise<any>;
    orderCategories(orderedCategoryIds: string[]): Promise<any>;
    getInterests(options: PagingOptions): Promise<PagedResult<profiling.ProfilingCategory>>;
    getInterest(id: string): Promise<profiling.ProfilingInterest>;
    createInterest(interest: profiling.ProfilingInterest): Promise<profiling.ProfilingInterest>;
    updateInterest(interest: profiling.ProfilingInterest): Promise<profiling.ProfilingInterest>;
    deleteInterest(id: string): Promise<any>;
    getFanAttributes(options: PagingOptions): Promise<PagedResult<profiling.ProfilingFanAttribute>>;
    getFanAttribute(id: string): Promise<profiling.ProfilingFanAttribute>;
    createFanAttribute(fanAttribute: profiling.ProfilingFanAttribute): Promise<profiling.ProfilingFanAttribute>;
    updateFanAttribute(fanAttribute: profiling.ProfilingFanAttribute): Promise<profiling.ProfilingFanAttribute>;
    deleteFanAttribute(id: string): Promise<any>;
    validateFanAttribute(id: string, updatedFanAttribute?: profiling.ProfilingFanAttribute): Promise<profiling.ProfilingFanAttribute>;
    unvalidateFanAttribute(id: string): Promise<profiling.ProfilingFanAttribute>;
    addAliases(id: string, idsToConvert: string[]): Promise<profiling.ProfilingFanAttribute>;
    getAllBadges(status?: BADGE_STATUS, options?: PagingOptions): Promise<any>;
    getBadge(badgeId: string): Promise<any>;
    createBadge(badge: Badge): Promise<any>;
    deleteBadge(badgeId: string): Promise<any>;
    updateBadge(badgeId: string, badge: Badge): Promise<any>;
    linkBadgeToFg(fanGroupId: string, badgeId: string): Promise<any>;
    unlinkBadgeToFg(fanGroupId: string, badgeId: string): Promise<any>;
    getBadges(fanGroupId: string): Promise<any>;
    getBadgeCategories(status?: BADGE_STATUS, options?: PagingOptions): Promise<any>;
    createBadgeCategory(category: Category): Promise<any>;
    updateBadgeCategory(categoryId: string, category: Category): Promise<any>;
    deleteBadgeCategory(categoryId: string): Promise<any>;
    getSurvey(id: string): Promise<survey.Survey>;
    getSurveys(options: PagingOptions): Promise<PagedResult<survey.Survey>>;
    createSurvey(data: survey.Survey): Promise<survey.Survey>;
    updateSurvey(data: survey.Survey): Promise<survey.Survey>;
    getSurveyInstance(id: string): Promise<survey.Survey>;
    getSurveyInstances(options: PagingOptions): Promise<PagedResult<survey.SurveyInstance>>;
    createSurveyInstances(surveyInstance: survey.SurveyInstance): Promise<survey.SurveyInstance>;
    updateSurveyInstances(surveyInstance: survey.SurveyInstance): Promise<survey.SurveyInstance>;
    getAnswerSemantic(id: string): Promise<survey.AnswerSemantic>;
    getAnswerSemantics(options: PagingOptions): Promise<PagedResult<survey.AnswerSemantic>>;
    createAnswerSemantic(answerSemantic: survey.AnswerSemantic): Promise<survey.AnswerSemantic>;
    updateAnswerSemantic(answerSemantic: survey.AnswerSemantic): Promise<survey.AnswerSemantic>;
    getQuestion(id: string): Promise<survey.Question>;
    getQuestions(options: PagingOptions): Promise<PagedResult<survey.Question>>;
    createQuestion(question: survey.Question): Promise<survey.Question>;
    updateQuestion(question: survey.Question): Promise<survey.Question>;
    getVenueConfig(venueId: string): Promise<PagedResult<VenueConfig>>;
    createEvent(event: Event): Promise<Event>;
    deleteEvent(eventId: string): Promise<any>;
    updatEvent(event: Event, eventId: any): Promise<Event>;
    createVenue(venue: any): Promise<Event>;
    createWishlist(groupId: string, wl: any): Promise<any>;
    openWishlist(wishlistId: string): Promise<any>;
    getWaitingListFull(waitingListId: string): Promise<any>;
    updateWaitingListFull(wl: any): Promise<any>;
    requestEventImageUpload(fanGroupId: string, fileName?: string): Promise<admin.OneTimeFile>;
    requestVoucherImageUpload(waitingListId: string, fileId?: string): Promise<any>;
    replaySignal(bus: any, id: any): Promise<any>;
    /**
     * HELPERS
     */
    private requestFanGroupImageUpload(fanGroupId, endpoint, fileName?);
}
