import { SeatersApiContext } from '../../seaters-api';
import { Fan } from '../fan';
import { AnonymousSignupData, AuthenticationSuccess, AuthToken, AuthTokenInput, EmailPasswordCredentials, RefreshTokenCredentials, ResetEmailData, ResetPasswordData, SignupData, StoredTokenCredentials, UserData, ValidationData } from './authentication-types';
import { IUpdatePasswordDTO } from '../fan/fan';
export declare class AuthenticationApi {
    private apiContext;
    constructor(apiContext: SeatersApiContext);
    /**
     * Login using email-password credentials
     * @param credentials email, password and optionally MFA token
     */
    emailPasswordLogin(credentials: EmailPasswordCredentials): Promise<AuthenticationSuccess>;
    /**
     * Login using long-term stored token
     * @param credentials long term stored token and optionally MFA token
     */
    storedTokenLogin(credentials: StoredTokenCredentials): Promise<AuthenticationSuccess>;
    /**
     * Extend your session with a refresh token
     * @param credentials Refresh token
     */
    refreshTokenLogin(credentials: RefreshTokenCredentials): Promise<AuthenticationSuccess>;
    /**
     * Signs up a new user
     * @param input
     * @returns {any}
     */
    signup(input: SignupData): Promise<UserData>;
    /**
     * Signs up a new user without firstname / lastname / password
     * @param input
     * @returns {any}
     */
    signupAnonymous(input: AnonymousSignupData): Promise<AuthenticationSuccess>;
    /**
     * Validates an email or phone number and marks it as confirmed
     *
     * @param input Either the email or the phone and the confirmation code
     * @returns Promise that resolves with the validated user or rejects with a SeatersApiException
     * @see SeatersApiException
     */
    validate(input: ValidationData): Promise<Fan>;
    /**
     *
     * @param input
     * @returns {any}
     */
    resetPassword(input: ResetPasswordData): Promise<void>;
    verifyOAuth(input: any): any;
    /**
     *
     * @param input
     * @returns {any}
     */
    resetEmail(input: ResetEmailData): Promise<void>;
    /**
     * Obtain a seaters session by passing an oauth code for a given provider
     * Examples that should work are github, facebook. For your specific provider name
     * please refer to a seaters developer.
     */
    loginWithOAuthCode(oauthProvider: string, code: string): Promise<AuthenticationSuccess>;
    /**
     * Create a new authentication token that can be stored and is valid for a longer time
     * for the authenticated user.
     */
    createStoredToken(input: AuthTokenInput): Promise<AuthToken>;
    /**
     * Get all stored tokens for authenticated user
     */
    getStoredTokens(): Promise<AuthToken[]>;
    /**
     * Update password
     * @param data
     */
    updatePassword(data: IUpdatePasswordDTO): Promise<AuthenticationSuccess>;
}
