import { PagedSortedResult, SeatersApiContext } from '../../seaters-api';
import { PagedResult } from '../paged-result';
import { PagingOptions } from '../paging-options';
import { TranslationMap } from '../translation-map';
import { Answer, AttendeeInfo, BraintreeToken, Fan, FanGroup, FanGroupFilterInfo, FanGroupLook, FanGroupRequest, FanGroupShare, Position, PositionSalesTransaction, PositionSalesTransactionInput, Price, ProfilingCategory, ProfilingFanAttribute, SurveyInstance, UserFanAttribute, UserInterestUpdateDTO, WaitingList, WaitingListFanAttribute, WaitingListInterest, WaitingListShare, AdditionalCharges, Badge } from './fan-types';
import { WaitingListRequest } from './waiting-list';
import { StringMap } from '../../api/string-map';
import { UserInterest } from './profiling';
import { PhoneNumber, UserFanAttributeUpdateDTO } from './index';
import { IUpdateEmailDTO, IUpdatePasswordDTO } from './fan';
import { payment } from '../../services/payment-service/payment-types';
import { BadgeGrantOptions, BadgeWlOptions, BadgeProtection } from './badges';
export declare class FanApi {
    private apiContext;
    constructor(apiContext: SeatersApiContext);
    fan(): Promise<Fan>;
    updateFan(fan: Fan): Promise<Fan>;
    updatePassword(data: IUpdatePasswordDTO): Promise<Fan>;
    updateEmail(data: IUpdateEmailDTO): Promise<Fan>;
    updateMobilePhoneNumber(data: PhoneNumber): Promise<Fan>;
    fanGroup(fanGroupId: string): Promise<FanGroup>;
    fanGroupBySlug(slug: string): Promise<FanGroup>;
    oauthAuthorizationCodeUrl(provider: string): Promise<any>;
    fanGroupLookBySlug(slug: string): Promise<FanGroupLook>;
    getOwnedFanGroups(pagingOptions?: PagingOptions): Promise<any>;
    fanGroupTranslatedDescription(fanGroupId: string): Promise<string>;
    hasGeoFilteredWaitingLists(fanGroupId: string): Promise<FanGroupFilterInfo>;
    fanGroups(fanGroupIds: string[]): Promise<FanGroup[]>;
    fanGroupLook(slug: string): Promise<FanGroupLook>;
    joinFanGroup(fanGroupId: string): Promise<FanGroup>;
    joinProtectedFanGroup(fg: FanGroup, code: string): Promise<FanGroupRequest>;
    leaveFanGroup(fanGroupId: string): Promise<void>;
    shareFanGroup(fanGroupId: string): Promise<FanGroupShare>;
    waitingListsInFanGroup(fanGroupId: string, pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<WaitingList>>;
    waitingListsInFanGroupByKeywords(groupIds: string, pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<WaitingList>>;
    requestOneTimeFileUpload(fileName?: string): Promise<any>;
    uploadOneTimeFile(oneTimeFileUrl: string, data: any): Promise<any>;
    updateWlImage(waitingListId: string, fileId: string): Promise<any>;
    addProperties(waitingListId: string, properties: any): Promise<any>;
    waitinglistAvailableSeats(waitingListId: string): Promise<any>;
    waitinglistParkingAvailableSeats(waitingListId: string): Promise<any>;
    waitingListTotalDemand(waitingListId: string): Promise<any>;
    waitingListsInFanGroups(fanGroupIds: string[], pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<WaitingList>>;
    joinedFanGroups(pagingOptions: PagingOptions): Promise<PagedResult<FanGroup>>;
    joinedWaitingListsWithoutSeat(pagingOptions: PagingOptions): Promise<PagedResult<WaitingList>>;
    joinedWaitingListsWithSeat(pagingOptions: PagingOptions): Promise<PagedResult<WaitingList>>;
    waitingListTranslatedVenueDescription(waitingListId: string): Promise<string>;
    waitingList(waitingListId: string): Promise<WaitingList>;
    waitingLists(waitingListIds: string[]): Promise<WaitingList[]>;
    getAdditionalInfos(waitingListId: string): Promise<any>;
    waitingListPrice(waitingListId: string, numberOfSeats: number): Promise<Price>;
    joinWaitingList(waitingListId: string, numberOfSeats: number, selectedSeats: any, additionalQueryParams: StringMap): Promise<WaitingList>;
    joinProtectedWaitingList(wl: WaitingList, code: string, numberOfSeats: number, additionalQueryParams: StringMap): Promise<WaitingListRequest>;
    shareWaitingList(waitingListId: string): Promise<WaitingListShare>;
    leaveWaitingList(waitingListId: string): Promise<void>;
    acceptSeats(waitingListId: string, formatUsed: string): Promise<WaitingList>;
    rejectSeats(waitingListId: string): Promise<WaitingList>;
    exportSeats(waitingListId: string, formatUsed: string): Promise<void>;
    sendExportedSeats(waitingListId: string): Promise<any>;
    positionPaymentInfo(waitingListId: string): Promise<payment.PaymentInfo>;
    positionBraintreeToken(waitingListId: string): Promise<BraintreeToken>;
    createPositionSalesTransaction(waitingListId: string, transaction: PositionSalesTransactionInput): Promise<PositionSalesTransaction>;
    getPositionSalesTransaction(waitingListId: string): Promise<PositionSalesTransaction>;
    sendPayCallback(reference: string): any;
    deletePositionSalesTransaction(waitingListId: string): Promise<any>;
    updateAttendeesInfo(waitingListId: string, attendeesInfo: AttendeeInfo[]): Promise<Position>;
    getEventDescription(waitingListId: string): Promise<TranslationMap>;
    searchEvent(eventName: string, date: string, pagingOptions?: PagingOptions): Promise<any>;
    searchVenues(venueName?: string, pagingOptions?: PagingOptions): Promise<any>;
    getVenueConditions(waitingListId: string): Promise<TranslationMap>;
    getTranslatedEventDescription(waitingListId: string): Promise<string>;
    getTranslatedVenueConditions(waitingListId: string): Promise<string>;
    getWaitingListsAsFGO(fanGroupId: string, searchOptions: any, pagingOptions?: PagingOptions): Promise<any>;
    getWaitingListAsFGO(waitingListId: string): Promise<any>;
    updateWaitingList(waitingList: any): Promise<any>;
    draftWaitingList(waitingListId: string): Promise<any>;
    openWaitingList(waitingListId: string): Promise<any>;
    closeWaitingList(waitingListId: string): Promise<any>;
    publishWaitingList(waitingListId: string): Promise<any>;
    scheduleWaitingList(waitingListId: string, date: string): Promise<any>;
    createWaitingList(fanGroupId: any, waitingList: any): Promise<any>;
    getPositions(waitingListId: any, query?: string, pagingOptions?: PagingOptions): Promise<any>;
    getSeats(waitingListId: any, query?: string, pagingOptions?: PagingOptions): Promise<any>;
    assignWaitingListSeatToFan(waitingListId: string, fanId: string): Promise<any>;
    assignWaitingListParkingSeatToFan(waitingListId: string, fanId: string): Promise<any>;
    assignWithoutSeats(waitingListId: string, fanId: string): Promise<any>;
    declineFanPosition(waitingListId: string, fanId: string): Promise<any>;
    removeFanFromWaitingList(waitingListId: string, fanId: string): Promise<any>;
    searchMember(fanGroupId: string, query: string, pagingOptions?: PagingOptions): Promise<any>;
    getFanInfo(fanId: string): Promise<any>;
    getFanAttribute(fanId: string): Promise<any>;
    getFanInterests(fanId: string): Promise<any>;
    getFanActivities(fanId: string, fanGroupId: string): Promise<any>;
    addPosition(waitingListId: string, fanId: string, params: any): Promise<any>;
    getExiredPositions(waitingListId: string, query: string): Promise<any>;
    addWaitingListTickets(waitingListId: string, totalTickets: number, ticketsToAdd: number): Promise<any>;
    waitinglistFinishedDistributing(waitingListId: string, nextDistributionNumber: any): Promise<any>;
    getAvailableSeats(wlId: any): Promise<any>;
    getSeatingMap(wlId: any): Promise<any>;
    getPickedSeats(wlId: any): Promise<any>;
    /**
     * Gets complete list of categories
     * @param {PagingOptions} pagingOptions
     */
    getProfilingCategories(pagingOptions?: PagingOptions): Promise<PagedSortedResult<ProfilingCategory>>;
    /**
     * Gets single category
     * @param categoryId
     */
    getProfilingCategoryById(categoryId: any): Promise<ProfilingCategory>;
    /**
     * Gets complete list of interests with their user status
     * and their categoryId
     *
     * @param pagingOptions
     */
    getUserInterests(pagingOptions?: PagingOptions): Promise<PagedSortedResult<UserInterest>>;
    /**
     * Updates a user interest
     * @param {UserInterestUpdateDTO} options
     */
    updateUserInterest(options: UserInterestUpdateDTO): Promise<UserInterest>;
    /**
     *
     * Performs search operation
     * on name and aliases of fan attribues
     *
     * @param {string} query search query
     * @param {boolean} validated to fetch only validated fan attributes
     *
     */
    seachFanAttributes(query: string, validated: boolean): Promise<ProfilingFanAttribute[]>;
    /**
     * Gets list of user fan attribute
     * @param pagingOptions
     */
    getUserFanAttributes(pagingOptions?: PagingOptions): Promise<PagedSortedResult<UserFanAttribute>>;
    /**
     * Gets single user fan attributes
     * @param fanAttributeId
     */
    getProfilingFanAttributeById(fanAttributeId: string): Promise<ProfilingFanAttribute>;
    /**
     * Updates user fan attribute
     * (Link / Unlink / Create )
     * @param {UserFanAttributeUpdateDTO} options
     */
    updateUserFanAttribute(options: UserFanAttributeUpdateDTO): Promise<UserFanAttribute>;
    getWaitingListCategories(pagingOptions?: PagingOptions): Promise<PagedSortedResult<ProfilingCategory>>;
    getWaitingListInterests(waitingListId: string): Promise<PagedSortedResult<WaitingListInterest>>;
    getWaitingListFanAttributes(waitingListId: string, pagingOptions: PagingOptions): Promise<PagedSortedResult<WaitingListFanAttribute>>;
    linkWaitingListInterest(waitingListId: string, interestId: string): Promise<WaitingListInterest>;
    linkWaitingListFanAttribute(waitingListId: string, fanAttributeId: string): Promise<WaitingListFanAttribute>;
    unlinkWaitingListInterest(waitingListId: string, interestId: string): Promise<WaitingListInterest>;
    unlinkWaitingListFanAttribute(waitingListId: string, fanAttributeId: string): Promise<WaitingListFanAttribute>;
    getBadges(fanGroupId: string, pagingOptions?: PagingOptions): Promise<PagedSortedResult<Badge>>;
    getBadgeProtection(waitingListId: string): Promise<BadgeProtection>;
    getUserBadges(fanGroupId: string, userId: string, pagingOptions?: PagingOptions): Promise<PagedSortedResult<Badge>>;
    getFanGroupBadges(fanGroupId: string, pagingOptions?: PagingOptions): Promise<PagedSortedResult<Badge>>;
    grantBadge(fanGroupId: string, body: BadgeGrantOptions): Promise<any>;
    revokeBadge(fanGroupId: string, body: BadgeGrantOptions): Promise<any>;
    linkBadgeToWl(waitingListId: string, body: BadgeWlOptions): Promise<any>;
    unlinkBadgeToWl(waitingListId: string, linkId: string): Promise<any>;
    relinkBadgeToWl(waitingListId: string, linkId: string): Promise<any>;
    getWLBadges(waitingListId: string, pagingOptions?: PagingOptions): Promise<any>;
    /**
     * Gets list of surveys per wishlist
     * @param {PagingOptions} pagingOptions
     */
    getSurveys(pagingOptions?: PagingOptions): Promise<PagedSortedResult<SurveyInstance>>;
    getChoices(questionId: string, pagingOptions?: any): any;
    addChoices(questionId: string, choices: any): any;
    getChoicesAsFO(questionId: string, pagingOptions?: any): any;
    /**
     * Gets list of answers for a given surveyInstanceId
     * @param {string} surveyInstanceId
     */
    getAnswers(surveyInstanceId: string): Promise<PagedSortedResult<Answer>>;
    /**
     * Submits list of answers for a given surveyInstanceId
     * @param {string} surveyInstanceId
     * @param {Answer[]} answers
     */
    submitAnswers(surveyInstanceId: string, answers: Answer[]): Promise<Answer[]>;
    /**
     * Gets list of surveys per wishlist
     * @param {string} waitingListId
     * @param {PagingOptions} pagingOptions
     */
    getWaitingListSurveys(waitingListId: string, pagingOptions?: PagingOptions): Promise<PagedSortedResult<SurveyInstance>>;
    /**
     * Gets list of answers for a given user, survey and waitinglist
     * @param {string} waitingListId
     * @param {string} surveyInstanceId
     * @param {PagingOptions} pagingOptions
     */
    getUserAnswers(waitingListId: string, surveyInstanceId: string, pagingOptions?: PagingOptions): Promise<PagedSortedResult<Answer>>;
    loadAdditionalCharges(waitingListId: string): Promise<AdditionalCharges[]>;
    getBasicConnectedAppToken(): Promise<any>;
    getJoinsCount(): Promise<any>;
}
