import { ApiContext, ApiRequestDefinition, ArrayMap, RequestDriver, StringMap } from '../api';
import { PagedResult, PagingOptions } from '../shared-types';
export declare class SeatersApiContext extends ApiContext {
    static buildPagingQueryParams(pagingOptions: PagingOptions): {
        [key: string]: any;
    };
    static buildPagingSortingQueryParams(pagingOptions: PagingOptions): {
        [key: string]: any;
    };
    static convertPagedResultToArray(promise: Promise<PagedResult<any>>): Promise<any[]>;
    constructor(prefix: string, requestDriver: RequestDriver);
    /**
     * Returns a promise that either resolves with the requested resource
     * or rejects on error with a SeatersApiException.
     *
     * @param requestDefinition Definition of which resource is requested
     *
     * @see SeatersApiException
     */
    doSeatersRequest(requestDefinition: ApiRequestDefinition): Promise<string>;
    doTypedSeatersRequest<T>(requestDefinition: ApiRequestDefinition): Promise<T>;
    get(abstractEndpoint: string, endpointParams?: StringMap, queryParams?: ArrayMap): Promise<any>;
    put(abstractEndpoint: string, body?: any, endpointParams?: StringMap, queryParams?: ArrayMap): Promise<any>;
    post(abstractEndpoint: string, body?: any, endpointParams?: StringMap, queryParams?: ArrayMap): Promise<any>;
    delete(abstractEndpoint: string, endpointParams?: StringMap, queryParams?: ArrayMap): Promise<any>;
    /**
     * For browser, we expect HTMLInputElement containing a file
     * @param oneTimeFileUrl url of a OneTimeFile returned by requestOneTimeFileUpload
     * @param data for browsers: HTMLInputElement, for node: not supported
     */
    uploadOneTimeFile(oneTimeFileUrl: string, data: any): Promise<any>;
    private handleServerResponse(response);
    private handle2XXResponse(response);
    private dataFromLegacyResponse(response);
    /**
     * (legacy) old endpoints return 400 with only a message string
     * This type of error is mapped to a proper SeatersApiException
     */
    private handle400Response(response);
    private createServerError(response, message);
    private handle401Response(response);
    private handle404Response(response);
    private handle422Response(response);
    private handleUnexpectedResponse(response);
    private handleClientError<T>(error);
    private parseResult(body);
}
