import { SeatersApiException } from './seaters-api-exception';
import { ServerResponse } from './../api';
export declare namespace SeatersExceptionV3 {
    type ERROR_TYPES = 'validation_errors' | 'technical_error';
    interface ValidationError {
        /**
         * The actual error that occurred
         */
        error: {
            /**
             * A coded string that can be used to check against certain errors.
             * Can be used as translation key prefix or suffix. Lower snake case formatted
             * See specific endpoint to know which error codes are possible
             *
             * e.g. invalid_email
             */
            errorCode: string;
            /**
             * Human readable version of the validation error
             */
            errorDescription: string;
        };
        /**
         * Reference string indicating which field(s) are causing the validation error.
         * e.g. attendees[0].email
         */
        references: string[];
        /**
         * Timestamp string - seems useless
         */
        timestamp: string;
    }
    interface ApiException {
        uuid: string;
        timestamp: string;
        errors: {
            detectedErrorTypes: ERROR_TYPES[];
            errorsTypes: {
                technical_error: any;
                validation_errors: ValidationError[];
            };
        };
    }
    /**
     * Map Seaters API V3 exceptions to a consistent format. This is the error view designed by Daniel Di Luca
     *
     * @param mapping A mapping of V3 error messages to values of the given type
     * @return Returns an Promise that rejects with the mapped error
     */
    function seatersExceptionV3Mapper<T>(res: ServerResponse): SeatersApiException;
}
