import { PagedResult, PagingOptions, SeatersApi, SeatersService } from '../common';
import { admin } from './admin-types';
import { profiling, survey } from '../index';
import { VenueConfig, Event } from '../../seaters-api/admin';
import { Badge, Category, BADGE_STATUS } from '../../seaters-api/fan';
import { PagedSortedResult } from '../../seaters-api';
export declare class AdminService extends SeatersService {
    constructor(seatersApi: SeatersApi);
    getEvent(eventId: string): Promise<admin.FanGroup>;
    getFanGroup(fanGroupId: string): Promise<admin.FanGroup>;
    getFanGroupProtectionCodes(fanGroupId: string, page: PagingOptions): Promise<PagedResult<admin.FanGroupProtectionCode>>;
    getFanGroupWaitingLists(fanGroupId: string, page: PagingOptions): Promise<PagedResult<admin.WaitingList>>;
    getWaitingList(waitingListId: string): Promise<admin.WaitingList>;
    updateWaitingList(waitingList: admin.WaitingList): Promise<admin.WaitingList>;
    deleteWaitingList(waitingListId: string): Promise<any>;
    deleteEvent(eventId: string): Promise<any>;
    scheduleClosingDate(waitingListId: string, date: string): Promise<any>;
    /**
     * Add a new protection code to a FanGroup
     * @param fanGroupId the id of the fangroup that can be unlocked with the code
     * @param code a text that can be used to unlock the fangroup
     * @param maxTimesUsed use 0 to describe unlimited code
     */
    createFanGroupProtectionCode(fanGroupId: string, code: string, maxTimesUsed: number): Promise<admin.FanGroupProtectionCode>;
    deleteFanGroupProtectionCode(fanGroupId: string, code: string): Promise<any>;
    /**
     * Import protection codes into a FanGroup. This upload should be a CSV with following format:
     * - column 1: the actual code that can unlock the FG
     * - column 2: how many times the code can be used - use 0 for infinite usage
     * @param fanGroupId The FG to import codes into
     * @param data For browser an HTMLInputElement containing a file, node: not supported
     */
    importFanGroupProtectionCodes(fanGroupId: string, data: any, fileName?: string): Promise<any>;
    updateFanGroupBackgroundImage(fanGroupId: string, data: any, fileName?: string): Promise<admin.FanGroup>;
    updateFanGroupCoverImage(fanGroupId: string, data: any, fileName?: string): Promise<admin.FanGroup>;
    updateFanGroupProfileImage(fanGroupId: string, data: any, fileName?: string): Promise<admin.FanGroup>;
    updateEventImage(eventId: string, data: any, fileName?: string): Promise<admin.FanGroup>;
    getCategories(options: PagingOptions): Promise<PagedResult<profiling.ProfilingCategory>>;
    getCategory(id: string): Promise<profiling.ProfilingCategory>;
    createCategory(category: profiling.ProfilingCategory): Promise<profiling.ProfilingCategory>;
    updateCategory(category: profiling.ProfilingCategory): Promise<profiling.ProfilingCategory>;
    deleteCategory(id: string): Promise<any>;
    orderCategories(orderedCategoryIds: string[]): Promise<any>;
    getInterests(options: PagingOptions): Promise<PagedResult<profiling.ProfilingCategory>>;
    getInterest(id: string): Promise<profiling.ProfilingInterest>;
    createInterest(interest: profiling.ProfilingInterest): Promise<profiling.ProfilingInterest>;
    updateInterest(interest: profiling.ProfilingInterest): Promise<profiling.ProfilingInterest>;
    deleteInterest(id: string): Promise<any>;
    getFanAttributes(options: PagingOptions): Promise<PagedResult<profiling.ProfilingFanAttribute>>;
    getFanAttribute(id: string): Promise<profiling.ProfilingFanAttribute>;
    createFanAttribute(fanAttribute: profiling.ProfilingFanAttribute): Promise<profiling.ProfilingFanAttribute>;
    updateFanAttribute(fanAttribute: profiling.ProfilingFanAttribute): Promise<profiling.ProfilingFanAttribute>;
    deleteFanAttribute(id: string): Promise<any>;
    validateFanAttribute(id: string, updatedFanAttribute?: profiling.ProfilingFanAttribute): Promise<profiling.ProfilingFanAttribute>;
    unvalidateFanAttribute(id: string): Promise<profiling.ProfilingFanAttribute>;
    addAliases(id: string, idsToConvert: string[]): Promise<profiling.ProfilingFanAttribute>;
    getAllBadges(status?: BADGE_STATUS, options?: PagingOptions): Promise<PagedSortedResult<Badge>>;
    getBadge(badgeId: string): Promise<Badge>;
    createBadge(badge: Badge): Promise<Badge>;
    deleteBadge(badgeId: string): Promise<any>;
    updateBadge(badgeId: string, badge: Badge): Promise<Badge>;
    linkBadgeToFg(fanGroupId: string, badgeId: string): Promise<any>;
    unlinkBadgeToFg(fanGroupId: string, badgeId: string): Promise<any>;
    getBadges(fanGroupId: string): Promise<PagedSortedResult<Badge>>;
    getBadgeCategories(status?: BADGE_STATUS, options?: PagingOptions): Promise<PagedSortedResult<Category>>;
    createBadgeCategory(category: Category): Promise<Category>;
    updateBadgeCategory(categoryId: string, category: Category): Promise<Category>;
    deleteBadgeCategory(categoryId: string): Promise<any>;
    getSurvey(id: string): Promise<survey.Survey>;
    getSurveys(options: PagingOptions): Promise<PagedResult<survey.Survey>>;
    createSurvey(data: survey.Survey): Promise<survey.Survey>;
    updateSurvey(data: survey.Survey): Promise<survey.Survey>;
    getSurveyInstance(id: string): Promise<survey.Survey>;
    getSurveyInstances(options: PagingOptions): Promise<PagedResult<survey.SurveyInstance>>;
    createSurveyInstances(surveyInstance: survey.SurveyInstance): Promise<survey.SurveyInstance>;
    updateSurveyInstances(surveyInstance: survey.SurveyInstance): Promise<survey.SurveyInstance>;
    getAnswerSemantic(id: string): Promise<survey.AnswerSemantic>;
    getAnswerSemantics(options: PagingOptions): Promise<PagedResult<survey.AnswerSemantic>>;
    createAnswerSemantic(answerSemantic: survey.AnswerSemantic): Promise<survey.AnswerSemantic>;
    updateAnswerSemantic(answerSemantic: survey.AnswerSemantic): Promise<survey.AnswerSemantic>;
    getQuestion(id: string): Promise<survey.Question>;
    getQuestions(options: PagingOptions): Promise<PagedResult<survey.Question>>;
    createQuestion(question: survey.Question): Promise<survey.Question>;
    updateQuestion(question: survey.Question): Promise<survey.Question>;
    getVenueConfig(venueId: string): Promise<PagedResult<VenueConfig>>;
    createEvent(event: Event): Promise<Event>;
    createVenue(venue: any): Promise<Event>;
    createWishlist(groupId: string, wishList: any): Promise<any>;
    openWishlist(wishlistId: string): Promise<any>;
    getWaitingListFull(waitingListId: string): Promise<any>;
    updateWaitingListFull(wl: any): Promise<any>;
    requestVoucherImageUpload(fanGroupId: string, fileName?: string): Promise<any>;
    replaySignal(bus: any, id: any): Promise<any>;
    updatEvent(event: any, eventId: any): any;
    private uploadOneTimeFile(data, fileName?);
    private defaultFileName(fileName?);
}
