import { SeatersApi } from '../../seaters-api';
import { app } from './app-types';
import { Address } from '../../seaters-api/fan';
export declare class AppService {
    private seatersApi;
    private envP;
    constructor(seatersApi: SeatersApi);
    /**
     * Fetch the application environment details
     */
    getEnv(): Promise<app.Env>;
    /**
     * Fetch a list of countries
     * @param page defaults to a page with maxPageSize set to anticipated maximum value
     */
    getCountries(): Promise<app.Country[]>;
    /**
     * Fetch a list of languages
     * @param page defaults to a page with maxPageSize set to anticipated maximum value
     */
    getLanguages(): Promise<app.Language[]>;
    /**
     * Fetch a list of currencies
     * @param page defaults to a page with maxPageSize set to anticipated maximum value
     */
    getCurrencies(): Promise<app.Currency[]>;
    /**
     * Fetch a list of time zones
     * @param page defaults to a page with maxPageSize set to anticipated maximum value
     */
    getTimeZones(): Promise<app.TimeZone[]>;
    /**
     * Fetch a list of translations
     * @param page defaults to a page with maxPageSize set to anticipated maximum value
     * @param target restrict to translations for the given target application
     * @param language restrict to translations in the given language (alpha-2 country code)
     */
    getTranslations(target?: app.TRANSLATION_TARGET, language?: string): Promise<app.Translation[]>;
    /**
     * Check if the API is in maintenance mode
     */
    isInMaintenance(): Promise<boolean>;
    /**
     * Based on the Accept-Language header this request will obtain
     * the best suited locale seaters has available for the user.
     * This method requires the actual request library to populate the
     * Accept-Language header; by default XHR populates this for most browsers.
     * It will work even without the header, but it will always return Seater's
     * default locale in this case.
     */
    getUserDefaultLocale(): Promise<string>;
    /**
     * Generates a seaters Address based
     * on a given google place
     * @param place google place https://developers.google.com/maps/documentation/javascript/reference/3/
     */
    generateSeatersAddress(place: any): Address;
    private getComponentName(type, place, nameLength?);
    private generateAddressLine1(placeObject, streetNumber, routeName);
    private generateCity(administrativeArea2, sublocality, localityLevel1, localityName, postalTownName);
}
