import { PagedResult, PagingOptions, SeatersApi, SeatersService } from '../common';
import { WaitingListService } from './waiting-list-service';
import { FanGroupService } from './fan-group-service';
import { fan } from './fan-types';
import { payment } from '../payment-service/payment-types';
import { profiling } from './profiling-types';
import { survey } from './survey-types';
import { LocalizableText } from '../util';
import { SessionService } from '../session-service';
import { PublicService } from '../public-service';
import { AttendeeInfo, Fan, PositionSalesTransactionInput, AdditionalCharges, Badge, BadgeGrantOptions, BadgeWlOptions } from '../../seaters-api/fan/fan-types';
import { BraintreeToken } from '../../seaters-api/fan/braintree-token';
import { IUpdateEmailDTO, IUpdatePasswordDTO, PhoneNumber } from '../../seaters-api/fan/fan';
import { StringMap } from '../../api/string-map';
import { FanProfilingService } from './fan-profiling-service';
import { FanSurveyService } from './fan-survey-service';
import { UserInterestUpdateDTO } from '../../seaters-api/fan';
import { PagedSortedResult } from '../../shared-types';
export declare class FanService extends SeatersService {
    private sessionService;
    private publicService;
    waitingListService: WaitingListService;
    fanGroupService: FanGroupService;
    fanProfilingService: FanProfilingService;
    fanSurveyService: FanSurveyService;
    constructor(seatersApi: SeatersApi, sessionService: SessionService, publicService: PublicService);
    /**
     *  FAN GROUPS
     */
    getFanGroups(fanGroupIds: string[]): Promise<fan.FanGroup[]>;
    getFanGroup(fanGroupId: string): Promise<fan.FanGroup>;
    getFanGroupBySlug(slug: string): Promise<fan.FanGroup>;
    getFanGroupLookBySlug(slug: string): Promise<fan.FanGroupLook>;
    getOwnedFanGroups(pagingOptions?: PagingOptions): Promise<any>;
    getFanGroupTranslatedDescription(fanGroupId: string): Promise<string>;
    joinFanGroup(fanGroupId: string): Promise<fan.FanGroup>;
    joinProtectedFanGroup(fanGroupId: string, code: string): Promise<fan.FanGroup>;
    requestToJoinPrivateFanGroup(fanGroupId: string): Promise<fan.FanGroup>;
    leaveFanGroup(fanGroupId: string): Promise<fan.FanGroup>;
    shareFanGroup(fanGroupId: string): Promise<fan.FanGroupShare>;
    hasGeoFilteredWaitingLists(fanGroupId: string): Promise<fan.FanGroupFilterInfo>;
    getJoinedFanGroups(pagingOptions: PagingOptions): Promise<PagedResult<fan.FanGroup>>;
    requestOneTimeFileUpload(fileName?: string): Promise<any>;
    uploadOneTimeFile(oneTimeFileUrl: string, data: any): Promise<any>;
    updateWlImage(waitingListId: string, fileId: string): Promise<any>;
    waitinglistAvailableSeats(waitingListId: string): Promise<any>;
    waitinglistParkingAvailableSeats(waitingListId: string): Promise<any>;
    waitingListTotalDemand(waitingListId: string): Promise<any>;
    assignWaitingListSeatToFan(waitingListId: string, fanId: string): Promise<any>;
    assignWaitingListParkingSeatToFan(waitingListId: string, fanId: string): Promise<any>;
    assignWithoutSeats(waitingListId: string, fanId: string): Promise<any>;
    declineFanPosition(waitingListId: string, fanId: string): Promise<any>;
    removeFanFromWaitingList(waitingListId: string, fanId: string): Promise<any>;
    searchMember(fanGroupId: string, query: string, pagingOptions?: PagingOptions): Promise<any>;
    getFanInfo(fanId: string): Promise<any>;
    getFanAttribute(fanId: string): Promise<any>;
    getFanInterests(fanId: string): Promise<any>;
    getFanActivities(fanId: string, fanGroupId: string): Promise<any>;
    addPosition(waitingListId: string, fanId: string, params: any): Promise<any>;
    getExiredPositions(waitingListId: string, query: string): Promise<any>;
    waitinglistFinishedDistributing(waitingListId: string, nextDistributionNumber: any): Promise<any>;
    /**
     *  WAITING LISTS
     */
    getWaitingList(waitingListId: string): Promise<fan.WaitingList>;
    getWaitingLists(waitingListIds: string[]): Promise<fan.WaitingList[]>;
    getWaitingListsInFanGroup(fanGroupId: string, pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<fan.WaitingList>>;
    getWaitingListsInFanGroupByKeywords(fanGroupId: string, pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<fan.WaitingList>>;
    getWaitingListsInFanGroups(fanGroupIds: string[], pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<fan.WaitingList>>;
    getMyWaitingListsWithoutSeat(page: PagingOptions): Promise<PagedResult<fan.WaitingList>>;
    getMyWaitingListsWithSeat(page: PagingOptions): Promise<PagedResult<fan.WaitingList>>;
    getWaitingListTranslatedVenueDescription(waitingListId: string): Promise<string>;
    getPositionBraintreePaymentInfo(waitingListId: string): Promise<payment.PaymentInfoBraintreeConfig>;
    getPositionSeatersPaymentInfo(waitingListId: string): Promise<payment.PaymentInfoSeatersConfig>;
    getPositionPaynlPaymentInfo(waitingListId: string): Promise<payment.PaymentInfoPaynlConfig>;
    joinWaitingList(waitingListId: string, numberOfSeats: number, selectedSeats: any, additionalQueryParams?: StringMap): Promise<fan.WaitingList>;
    joinProtectedWaitingList(waitingListId: string, code: string, numberOfSeats: number, additionalQueryParams?: StringMap): Promise<fan.WaitingList>;
    shareWaitingList(waitingListId: string): Promise<fan.WaitingListShare>;
    leaveWaitingList(waitingListId: string): Promise<fan.WaitingList>;
    getPositionPaymentInfo(waitingListId: string): Promise<payment.PaymentInfo>;
    payPosition(waitingListId: string, transaction: PositionSalesTransactionInput): Promise<fan.WaitingList>;
    sendPendingPayment(waitingListId: string, transaction: PositionSalesTransactionInput): any;
    checkIfGoLive(waitingListId: string): any;
    deleteSalesTransaction(waitingListId: string): any;
    getSalesTransaction(waitingListId: string): any;
    sendPayCallback(reference: string): any;
    preauthorizePosition(waitingListId: string, transaction: PositionSalesTransactionInput): Promise<fan.WaitingList>;
    /**
     * Submit attendee information. This will validate the submitted information. The returned promise will be
     * resolved once the user can continue with the next step after submitting attendee information
     * @param waitingListId WL for which attendee info needs to be validated and stored
     * @param attendeesInfo The actual attendee information
     * @throws SeatersApiException of type 'validation_error'
     */
    saveAttendeesInfo(waitingListId: string, attendeesInfo: AttendeeInfo[]): Promise<fan.WaitingList>;
    acceptSeats(waitingListId: string, formatUsed: string): Promise<fan.WaitingList>;
    rejectSeats(waitingListId: string): Promise<fan.WaitingList>;
    exportSeats(waitingListId: string, formatUsed: string): Promise<fan.WaitingList>;
    sendExportedSeats(waitingListId: string): Promise<any>;
    getEventDescriptionForWaitingList(waitingListId: string): Promise<LocalizableText>;
    searchEvent(eventName: string, date: string, pagingOptions?: PagingOptions): Promise<any>;
    searchVenues(venueName?: string, pagingOptions?: PagingOptions): Promise<any>;
    getTranslatedEventDescriptionForWaitingList(waitingListId: string): Promise<string>;
    getVenueConditionsForWaitingList(waitingListId: string): Promise<LocalizableText>;
    getTranslatedVenueConditionsForWaitingList(waitingListId: string): Promise<string>;
    positionBraintreeToken(waitingListId: string): Promise<BraintreeToken>;
    getWaitingListPrice(waitingListId: string, numberOfSeats: number): Promise<fan.Price>;
    createWaitingList(fanGroupId: any, waitingList: any): Promise<any>;
    /**
     * FANS
     */
    /**
     * Get current logged in fan
     * @returns {fan.Fan}
     */
    fan(): Promise<Fan>;
    /**
     * Send a new SMS containing the code needed to validate email / phone.
     * @param phone
     * @returns {any}
     */
    sendValidationCodeViaSMS(phone: PhoneNumber): Promise<Fan>;
    /**
     *  COMBINATIONS
     */
    updateFan(f: Fan): Promise<Fan>;
    updatePassword(data: IUpdatePasswordDTO): Promise<Fan>;
    updateEmail(data: IUpdateEmailDTO): Promise<Fan>;
    updateMobilePhoneNumber(data: PhoneNumber): Promise<Fan>;
    getWaitingListsByKeywords(keywords: string[], page: PagingOptions): Promise<PagedResult<fan.WaitingList>>;
    getProfilingCategories(pagingOptions: any): Promise<PagedResult<profiling.ProfilingCategory>>;
    getProfilingCategoryById(categoryId: string): Promise<profiling.ProfilingCategory>;
    seachFanAttributes(query: string, validated: boolean): Promise<profiling.ProfilingFanAttribute[]>;
    getProfilingFanAttributeById(fanAttributeId: string): Promise<profiling.ProfilingFanAttribute>;
    getUserInterests(pagingOptions: any): Promise<PagedResult<profiling.UserInterest>>;
    updateUserInterest(userInterestUpdateDTO: UserInterestUpdateDTO): Promise<profiling.UserInterest>;
    getUserFanAttributes(pagingOptions?: any): Promise<PagedResult<profiling.UserFanAttribute>>;
    updateUserFanAttribute(options: any): Promise<profiling.UserFanAttribute>;
    getWaitingListCategories(pagingOptions: any): Promise<PagedResult<profiling.ProfilingCategory>>;
    getWaitingListInterests(waitingListId: string): Promise<PagedResult<profiling.WaitingListInterest>>;
    getWaitingListFanAttributes(waitingListId: string, pagingOptions: any): Promise<PagedResult<profiling.WaitingListFanAttribute>>;
    linkWaitingListInterest(waitingListId: string, interestId: string): Promise<profiling.WaitingListInterest>;
    linkWaitingListFanAttribute(waitingListId: string, fanAttributeId: string): Promise<profiling.WaitingListFanAttribute>;
    unlinkWaitingListInterest(waitingListId: string, interestId: string): Promise<profiling.WaitingListInterest>;
    unlinkWaitingListFanAttribute(waitingListId: string, fanAttributeId: string): Promise<profiling.WaitingListFanAttribute>;
    getBadges(fanGroupId: string, pagingOptions?: PagingOptions): Promise<PagedSortedResult<Badge>>;
    isBadgeProtected(fanGroupId: string, waitingListId: string): Promise<boolean>;
    getBadgesProtection(fanGroupId: string, waitingListId: string): Promise<any>;
    getUserBadges(fanGroupId: string, userId: string, pagingOptions?: PagingOptions): Promise<PagedSortedResult<Badge>>;
    getFanGroupBadges(fanGroupId: string, pagingOptions?: PagingOptions): Promise<PagedSortedResult<Badge>>;
    grantBadge(fanGroupId: string, badgeGrantOptions: BadgeGrantOptions): Promise<any>;
    revokeBadge(fanGroupId: string, badgeGrantOptions: BadgeGrantOptions): Promise<any>;
    linkBadgeToWl(waitingListId: string, badgeGrantOptions: BadgeWlOptions): Promise<any>;
    unlinkBadgeToWl(waitingListId: string, linkId: string): Promise<any>;
    relinkBadgeToWl(waitingListId: string, linkId: string): Promise<any>;
    getWLBadges(waitingListId: string, pagingOptions?: PagingOptions): Promise<any>;
    updateWaitingList(waitingList: any): Promise<any>;
    draftWaitingList(waitingListId: string): Promise<any>;
    openWaitingList(waitingListId: string): Promise<any>;
    scheduleWaitingList(waitingListId: string, date: string): Promise<any>;
    closeWaitingList(waitingListId: string): Promise<any>;
    publishWaitingList(waitingListId: string): Promise<any>;
    addWaitingListTickets(waitingListId: string, totalTickets: number, ticketsToAdd: number): Promise<any>;
    getPositions(waitingListId: string, query?: string, pagingOptions?: PagingOptions): Promise<any>;
    getSeats(waitingListId: string, query?: string, pagingOptions?: PagingOptions): Promise<any>;
    getSurveys(waitingListId: string, extensionPoint: survey.SURVEY_EXTENSION_POINT, fanGroupId?: string): Promise<PagedResult<survey.SurveyInstance>>;
    getAnswers(surveyId: string): Promise<PagedResult<survey.Answer>>;
    submitAnswers(surveyId: string, answers: survey.Answer[]): Promise<survey.Answer[]>;
    getChoices(questionId: string, pagingOptions?: any): any;
    addChoices(questionId: string, choices: any): any;
    getChoicesAsFO(questionId: string, pagingOptions?: any): any;
    getWaitingListSurveys(waitingListId: string, extensionPoint: survey.SURVEY_EXTENSION_POINT): Promise<PagedResult<survey.SurveyInstance>>;
    getUserAnswers(waitingListId: string, surveyId: string, userId: string): Promise<PagedResult<survey.Answer>>;
    loadAdditionalCharges(waitingListId: string): Promise<AdditionalCharges[]>;
    getWaitingListsAsFGO(fanGroupId: string, searchOptions: any, pagingOptions?: PagingOptions): Promise<any>;
    getWaitingListAsFGO(waitingListId: string): Promise<any>;
    getAdditionalInfos(waitingListId: string): Promise<any>;
    getAvailableSeats(waitingListId: string): Promise<any>;
    addProperties(waitingListId: string, properties: any): Promise<any>;
    getSeatingMap(waitingListId: string): Promise<any>;
    getPickedSeats(waitingListId: string): Promise<any>;
    getBasicConnectedAppToken(): Promise<any>;
}
