import { PagedResult, SeatersApi } from '../../seaters-api';
import { AttendeeInfo, PositionSalesTransactionInput } from '../../seaters-api/fan';
import { fan } from './fan-types';
import { profiling } from './profiling-types';
import { TranslationMap } from '../../seaters-api/translation-map';
import { BraintreeToken } from '../../seaters-api/fan/braintree-token';
import { StringMap } from '../../api/string-map';
import { PagedSortedResult, PagingOptions } from '../../index';
import { payment } from '../payment-service/payment-types';
export declare class WaitingListService {
    private api;
    constructor(api: SeatersApi);
    getWaitingList(waitingListId: string): Promise<fan.WaitingList>;
    getWaitingLists(waitingListIds: string[]): Promise<fan.WaitingList[]>;
    getWaitingListsInFanGroup(fanGroupId: string, pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<fan.WaitingList>>;
    getWaitingListsInFanGroupByKeywords(fanGroupId: string, pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<fan.WaitingList>>;
    getWaitingListsInFanGroups(fanGroupIds: string[], pagingOptions: PagingOptions, keyWords?: string): Promise<PagedResult<fan.WaitingList>>;
    getMyWaitingListsWithoutSeat(page: PagingOptions): Promise<PagedResult<fan.WaitingList>>;
    getMyWaitingListsWithSeat(page: PagingOptions): Promise<PagedResult<fan.WaitingList>>;
    getWaitingListTranslatedVenueDescription(waitingListId: string): Promise<string>;
    getPositionBraintreePaymentInfo(waitingListId: string): Promise<payment.PaymentInfoBraintreeConfig>;
    getPositionSeatersPaymentInfo(waitingListId: string): Promise<payment.PaymentInfoSeatersConfig>;
    getPositionPaynlPaymentInfo(waitingListId: string): Promise<any>;
    joinWaitingList(waitingListId: string, numberOfSeats: number, selectedSeats: any, additionalQueryParams: StringMap): Promise<fan.WaitingList>;
    joinProtectedWaitingList(waitingListId: string, code: string, numberOfSeats: number, additionalQueryParams: StringMap): Promise<fan.WaitingList>;
    shareWaitingList(waitingListId: string): Promise<fan.WaitingListShare>;
    leaveWaitingList(waitingListId: string): Promise<fan.WaitingList>;
    getPositionPaymentInfo(waitingListId: string): Promise<payment.PaymentInfo>;
    payPosition(waitingListId: string, transaction: PositionSalesTransactionInput): Promise<fan.WaitingList>;
    sendPendingPayment(waitingListId: string, transaction: PositionSalesTransactionInput): any;
    sendPayCallback(reference: string): any;
    checkIfGoLive(waitingListId: string): any;
    getSalesTransaction(waitingListId: string): any;
    deleteSalesTransaction(waitingListId: string): any;
    preauthorizePosition(waitingListId: string, transaction: PositionSalesTransactionInput): Promise<fan.WaitingList>;
    saveAttendeesInfo(waitingListId: string, attendeesInfo: AttendeeInfo[]): Promise<fan.WaitingList>;
    acceptSeats(waitingListId: string, formatUsed: string): Promise<fan.WaitingList>;
    rejectSeats(waitingListId: string): Promise<fan.WaitingList>;
    exportSeats(waitingListId: string, formatUsed: string): Promise<fan.WaitingList>;
    getEventDescriptionForWaitingList(waitingListId: string): Promise<TranslationMap>;
    getTranslatedEventDescriptionForWaitingList(waitingListId: string): Promise<string>;
    getVenueConditionsForWaitingList(waitingListId: string): Promise<TranslationMap>;
    getTranslatedVenueConditionsForWaitingList(waitingListId: string): Promise<string>;
    positionBraintreeToken(waitingListId: string): Promise<BraintreeToken>;
    getWaitingListPrice(waitingListId: string, numberOfSeats: number): Promise<fan.Price>;
    getWaitingListCategories(pagingOptions: any): Promise<PagedSortedResult<profiling.ProfilingCategory>>;
    getWaitingListInterests(waitingListId: string): Promise<PagedSortedResult<profiling.WaitingListInterest>>;
    getWaitingListFanAttributes(waitingListId: string, pagingOptions: PagingOptions): Promise<PagedSortedResult<profiling.WaitingListFanAttribute>>;
    linkWaitingListInterest(waitingListId: string, interestId: string): Promise<profiling.WaitingListInterest>;
    linkWaitingListFanAttribute(waitingListId: string, fanAttributeId: string): Promise<profiling.WaitingListFanAttribute>;
    unlinkWaitingListInterest(waitingListId: string, interestId: string): Promise<profiling.WaitingListInterest>;
    unlinkWaitingListFanAttribute(waitingListId: string, fanAttributeId: string): Promise<profiling.WaitingListFanAttribute>;
    loadAdditionalCharges(waitingListId: string): Promise<fan.AdditionalCharges[]>;
    private hasPreviousPayment(wl);
    private hasPaymentInProgress(wl);
    private canPay(wl);
    private checkUnlockStatus(wl);
    private getRawWaitingList(waitingListId);
    private extendRawWaitingList(wl);
    private extendRawWaitingLists(wls);
    private pollWaitingList(waitingListId, condition, limit?, delayInMs?, useRawWaitingList?);
    private getWaitingListActionStatus(waitingList);
    private waitForDirectSales(wl);
    private waitForVoucher(wl);
    private hasVoucher(wl);
    private seatHasVoucherNumber(wl);
    private hasTicket(wl);
    private seatsCanBeExported(wl);
    private waitUntilCanGoLive(waitingListId, useRawWishList?);
    private waitUntilSeatsCanBeExported(waitingListId);
    private shouldProvideAttendeesInfo(wl);
    private submitTransaction(waitingListId, transaction);
    private ensureFanCanPayPosition(wl);
    private removePreviousTransactionIfAny(wl);
    private createTransaction(waitingListId, transaction);
    private hasProcessedPayment(wl);
    private hasFailedPayment(wl);
}
